@@ -8,8 +8,9 @@ CallableFunctionDescriptorStr = th.Union[
 FunctionDescriptor = th.Union[
     th.Callable, CallableFunctionDescriptorStr
 ]  # either a function or a function descriptor (str, dict)
-ContextType = th.Union[th.Dict[str, th.Any], types.ModuleType, th.Any]  # anything that we can get items from
-
+ContextType = th.Union[
+    th.Dict[str, th.Any], types.ModuleType, th.Any
+]  # anything that we can get items from
 
 # a singleton object to represent the absence of a value
 class _NoValue:
