@@ -1,4 +1,4 @@
 from dycode.wrappers.method_wrapper import dynamize_methods
 from dycode.wrappers.method_wrapper import dynamic_method as method
-from dycode.wrappers.field_wrapper import dynamize_fields, field
+from dycode.wrappers.field_wrapper import dynamize_fields, field, composite
 from dycode.wrappers.full_wrapper import dynamize
